==> ejc-cefoctest-impl-3.0.0-20230529.031142-4-sources.jar: com/ejianc/cefoc/bean/SealApplyEntity.java <==
package com.ejianc.cefoc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用印申请表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_c_oa_sealapply")
public class SealApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0 自由态，1 已提交， 2/6审批中，3 审批通过，4 驳回，5 提交后有人审批中
    @TableField(value="dept_sid")
    private String deptSid; // 部门sid
    @TableField(value="dept_name")
    private String deptName; // 部门名称
    @TableField(value="manager_name")
    private String managerName; // 部门经理
    @TableField(value="manager_sid")
    private String managerSid; // 部门经理主键
    @TableField(value="sealdate")
    private Date sealdate; // 使用日期
    @TableField(value="sealreason")
    private String sealreason; // 用印事由
    @TableField(value="title")
    private String title; // 审批主题
    
    
    

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getDeptSid() {
        return deptSid;
    }

    public void setDeptSid(String deptSid) {
        this.deptSid = deptSid;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public String getManagerSid() {
        return managerSid;
    }

    public void setManagerSid(String managerSid) {
        this.managerSid = managerSid;
    }
    public Date getSealdate() {
        return sealdate;
    }

    public void setSealdate(Date sealdate) {
        this.sealdate = sealdate;
    }
    public String getSealreason() {
        return sealreason;
    }

    public void setSealreason(String sealreason) {
        this.sealreason = sealreason;
    }
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }
    
}

==> ejc-cefoctest-impl-3.0.0-20230608.092646-12-sources.jar: com/ejianc/cefoc/bean/SealApplyEntity.java <==
package com.ejianc.cefoc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import org.joda.time.DateTime;

/**
 * 用印申请表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_c_oa_sealapply")
public class SealApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0 自由态，1 已提交， 2/6审批中，3 审批通过，4 驳回，5 提交后有人审批中
    @TableField(value="dept_sid")
    private Long deptSid; // 部门sid
    @TableField(value="dept_name")
    private String deptName; // 部门名称
    @TableField(value="manager_name")
    private String managerName; // 部门经理
    @TableField(value="manager_sid")
    private long managerSid; // 部门经理主键
    @TableField(value="sealdate")
    private Date sealdate; // 使用日期
    @TableField(value="sealreason")
    private String sealreason; // 用印事由
    @TableField(value="title")
    private String title; // 审批主题



    @TableField(value="org_id")
    private long orgId; // 审批主题



    public long getOrgId() {
        return orgId;
    }

    public void setOrgId(long orgId) {
        this.orgId = orgId;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getDeptSid() {
        return deptSid;
    }

    public void setDeptSid(Long deptSid) {
        this.deptSid = deptSid;
    }
    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }
    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public long getManagerSid() {
        return managerSid;
    }

    public void setManagerSid(long managerSid) {
        this.managerSid = managerSid;
    }
    public Date getSealdate() {
        return sealdate;
    }

    public void setSealdate(Date sealdate) {
        this.sealdate = sealdate;
    }
    public String getSealreason() {
        return sealreason;
    }

    public void setSealreason(String sealreason) {
        this.sealreason = sealreason;
    }
    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }
    
}
